@@ -74,7 +74,7 @@ horizon.forms = {
       if ($option.val() == "subnetpool") {
         $ipVersion.attr("disabled", "disabled");
       } else {
-        $ipVersion.removeAttr("disabled");
+        $ipVersion.prop("disabled", false);
       }
     });
   },
@@ -168,11 +168,11 @@ horizon.forms = {
         endDate.hide();
       }).data('datepicker');
 
-    $("#id_start").mousedown(function(){
+    $("#id_start").on("mousedown", function() {
       endDate.hide();
     });
 
-    $("#id_end").mousedown(function(){
+    $("#id_end").on("mousedown", function() {
       startDate.hide();
     });
 
@@ -184,12 +184,12 @@ horizon.forms = {
 
 horizon.forms.handle_submit = function (el) {
   var $form = $(el).find("form");
-  $form.submit(function () {
+  $form.on('submit', function () {
     var $this = $(this);
     // Disable multiple submissions when launching a form.
     var button = $this.find('[type="submit"]');
     if (button.hasClass('btn-primary') && !button.hasClass('always-enabled')){
-      $this.submit(function () {
+      $this.on('submit', function () {
         return false;
       });
       button.removeClass('primary').addClass('disabled');
@@ -198,7 +198,7 @@ horizon.forms.handle_submit = function (el) {
     // Remove disabled attribute on select fields before submit to get value
     // included in POST request.
     $this.find('select[disabled="disabled"]').each(function (i, field) {
-      $(field).removeAttr("disabled");
+      $(field).prop("disabled", false);
     });
     return true;
   });
@@ -228,7 +228,7 @@ horizon.forms.add_password_fields_reveal_buttons = function (el) {
     $input.closest('div').addClass("has-feedback");
     $('<span>').addClass(
       "form-control-feedback fa fa-eye password-icon"
-    ).insertAfter($input).click(function () {
+    ).insertAfter($input).on('click', function () {
       var $icon = $(this);
 
       if ($input.attr('type') === 'password') {
@@ -279,7 +279,7 @@ horizon.forms.init_themable_select = function ($elem) {
 
     // Set the select if necessary
     if ($select.val() !== value) {
-      $select.val(value).change();
+      $select.val(value).trigger("change");
     }
   });
 
@@ -318,7 +318,7 @@ horizon.forms.init_themable_select = function ($elem) {
       }
 
       // Add the new list to the dropdown.
-      $select.siblings('.dropdown-menu').html(list).change();
+      $select.siblings('.dropdown-menu').html(list).trigger("change");
       $select.trigger('change');
     });
 
@@ -379,7 +379,7 @@ horizon.forms.checkSpinnerValue = function($inputs) {
     var $up = $parent.find('.spinner-up');
     var $down = $parent.find('.spinner-down');
 
-    $parent.find('.themable-spinner-btn').removeAttr('disabled');
+    $parent.find('.themable-spinner-btn').prop('disabled', false);
     if (val <= min) {
 
       // Disable if we've hit the min
@@ -516,7 +516,7 @@ horizon.addInitFunction(horizon.forms.init = function () {
           //The required verification should be removed and recorded
           if ($input.attr('required') === 'required') {
             $input.data('savedRequired', 'required');
-            $input.removeAttr('required');
+            $input.prop('required', false);
           }
         } else {
           //If the input is a checkbox no need to replace html for label since it has another structure
