@@ -1,3 +1,17 @@
+/**
+ * Licensed under the Apache License, Version 2.0 (the "License"); you may
+ * not use this file except in compliance with the License. You may obtain
+ * a copy of the License at
+ *
+ *    http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+ * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+ * License for the specific language governing permissions and limitations
+ * under the License.
+ */
+
 /* Namespace for core functionality related to Membership Workflow Step. */
 horizon.membership = {
 
@@ -7,14 +21,25 @@ horizon.membership = {
   has_roles: [],
   default_role_id: [],
 
-  /* Parses the form field selector's ID to get either the
-   * role or user id (i.e. returns "id12345" when
-   * passed the selector with id: "id_group_id12345").
+  /* Parses the form field selector's ID to get the
+   * role id. It returns the string after the last underscore.
+   * (i.e. returns "id12345" when passed the selector with
+   * id: "id_group_id12345").
    **/
   get_field_id: function(id_string) {
     return id_string.slice(id_string.lastIndexOf("_") + 1);
   },
 
+  /*
+   * Parses the form field selector's ID to get the member
+   * user id, which is usually right after the step slug.
+   * (i.e. returns "aa_bb" when passed the selector with
+   * id: "id_update_members_aa_bb").
+   **/
+  get_member_id: function(id_string, step_slug) {
+    return id_string.slice(id_string.indexOf(step_slug) + step_slug.length + 1);
+  },
+
   /*
    * Gets the html select element associated with a given
    * role id.
@@ -227,7 +252,7 @@ horizon.membership = {
   generate_html: function(step_slug) {
     var data_id, data = horizon.membership.data[step_slug];
     for (data_id in data) {
-      if(data.hasOwnProperty(data_id)){
+      if (data.hasOwnProperty(data_id)) {
         var display_name = data[data_id];
         var role_ids = this.get_member_roles(step_slug, data_id);
         if (role_ids.length > 0) {
@@ -248,7 +273,7 @@ horizon.membership = {
     $(".available_" + step_slug + ", ." + step_slug + "_members").on('click', ".btn-group a[href='#add_remove']", function (evt) {
       evt.preventDefault();
       var available = $(".available_" + step_slug).has($(this)).length;
-      var data_id = horizon.membership.get_field_id($(this).parent().siblings().attr('data-' + step_slug + '-id'));
+      var data_id = horizon.membership.get_member_id($(this).parent().siblings().attr('data-' + step_slug + '-id'), step_slug);
       var member_el = $(this).parent().parent();
 
       if (available) {
@@ -293,7 +318,7 @@ horizon.membership = {
       }
       else {
         $('#no_' + filter).hide();
-        $("input[id='" + filter + "']").removeAttr('disabled');
+        $("input[id='" + filter + "']").prop('disabled', false);
       }
     });
   },
@@ -309,7 +334,7 @@ horizon.membership = {
       // get the newly selected role and the member's name
       var new_role_id = $(this).attr("data-role-id");
       var id_str = $(this).parent().parent().siblings(".member").attr("data-" + step_slug + "-id");
-      var data_id = horizon.membership.get_field_id(id_str);
+      var data_id = horizon.membership.get_member_id(id_str, step_slug);
       // update role lists
       if ($(this).hasClass('selected')) {
         $(this).removeClass('selected');
@@ -390,7 +415,7 @@ horizon.membership = {
    **/
   list_filtering: function (step_slug) {
     // remove previous lists' quicksearch events
-    $('input.' + step_slug + '_filter').unbind();
+    $('input.' + step_slug + '_filter').off();
 
     // set up quicksearch to filter on input
     $('.' + step_slug + '_filterable').each(function () {
@@ -421,7 +446,7 @@ horizon.membership = {
         },
         'testQuery': function (query, txt, span) {
           if ($(input).attr('id') === filter) {
-            $(input).prev().removeAttr('disabled');
+            $(input).prev().prop('disabled', false);
             return query.test($(span).text());
           } else {
             return true;
@@ -461,12 +486,12 @@ horizon.membership = {
 
       // unfocus filter fields
       if (step_id.indexOf('update') === 0) {
-        $form.find("#" + step_id + " input").blur();
+        $form.find("#" + step_id + " input").trigger('blur');
       }
 
       // prevent filter inputs from submitting form on 'enter'
-      $form.find('.' + step_slug + '_membership').keydown(function(event){
-        if(event.keyCode === 13) {
+      $form.find('.' + step_slug + '_membership').on('keydown', function(event){
+        if (event.keyCode === 13) {
           event.preventDefault();
           return false;
         }
