@@ -13,15 +13,19 @@
 #    under the License.
 
 from collections import OrderedDict
-import sys
-
-import six
+import logging
+import operator
 
+from django.conf import settings
 from django.template.loader import render_to_string
-from django.template import TemplateSyntaxError  # noqa
+from django.template import TemplateSyntaxError
+from django.utils import module_loading
 
 from horizon import exceptions
 from horizon.utils import html
+from horizon.utils import settings as utils_settings
+
+LOG = logging.getLogger(__name__)
 
 SEPARATOR = "__"
 CSS_TAB_GROUP_CLASSES = ["nav", "nav-tabs", "ajax-tabs"]
@@ -30,13 +34,17 @@ CSS_DISABLED_TAB_CLASSES = ["disabled"]
 
 
 class TabGroup(html.HTMLElement):
-    """A container class which knows how to manage and render
-    :class:`~horizon.tabs.Tab` objects.
+    """A container class which knows how to manage and render Tab objects.
 
     .. attribute:: slug
 
         The URL slug and pseudo-unique identifier for this tab group.
 
+    .. attribute:: tabs
+
+       A list of :class:`.Tab` classes. Tabs specified here are displayed
+       in the order of the list.
+
     .. attribute:: template_name
 
         The name of the template which will be used to render this tab group.
@@ -95,7 +103,7 @@ class TabGroup(html.HTMLElement):
         return self._active
 
     def __init__(self, request, **kwargs):
-        super(TabGroup, self).__init__()
+        super().__init__()
         if not hasattr(self, "tabs"):
             raise NotImplementedError('%s must declare a "tabs" attribute.'
                                       % self.__class__)
@@ -105,15 +113,55 @@ class TabGroup(html.HTMLElement):
         self.request = request
         self.kwargs = kwargs
         self._data = None
-        tab_instances = []
-        for tab in self.tabs:
-            tab_instances.append((tab.slug, tab(self, request)))
-        self._tabs = OrderedDict(tab_instances)
+        self._tabs = self._load_tabs(request)
         if self.sticky:
             self.attrs['data-sticky-tabs'] = 'sticky'
         if not self._set_active_tab():
             self.tabs_not_available()
 
+    def _load_tabs(self, request):
+        tabs = tuple(self.tabs)
+        tabs += self._load_tabs_from_config()
+        return OrderedDict([(tab.slug, tab(self, request))
+                            for tab in tabs])
+
+    def _load_tabs_from_config(self):
+        my_name = '.'.join([self.__class__.__module__,
+                            self.__class__.__name__])
+        horizon_config = settings.HORIZON_CONFIG.get('extra_tabs', {})
+        tabs_config = [self._load_tab_config(tab_config, my_name)
+                       for tab_config in horizon_config.get(my_name, [])]
+        tabs_config = [t for t in tabs_config if t]
+        tabs_config.sort(key=operator.itemgetter(0))
+        LOG.debug('Loaded extra tabs for %s: %s',
+                  my_name, tabs_config)
+        return tuple(x[1] for x in tabs_config)
+
+    @staticmethod
+    def _load_tab_config(tab_config, my_name):
+        if isinstance(tab_config, str):
+            tab_config = (0, tab_config)
+        if not isinstance(tab_config, (tuple, list)):
+            LOG.error('Extra tab definition must be a string or '
+                      'a tuple/list (tab group "%s")', my_name)
+            return
+        if len(tab_config) != 2:
+            LOG.error('Entry must be a format of (priority, tab class) '
+                      '(tab group "%s")', my_name)
+            return
+        priority, tab_class = tab_config
+        if not isinstance(priority, int):
+            LOG.error('Priority of tab entry must be an integer '
+                      '(tab group "%s")', my_name)
+            return
+        try:
+            class_ = module_loading.import_string(tab_class)
+        except ImportError:
+            LOG.error('Tab class "%s" is not found (tab group "%s")',
+                      tab_class, my_name)
+            return
+        return priority, class_
+
     def __repr__(self):
         return "<%s: %s>" % (self.__class__.__name__, self.slug)
 
@@ -128,25 +176,29 @@ class TabGroup(html.HTMLElement):
                     exceptions.handle(self.request)
 
     def get_id(self):
-        """Returns the id for this tab group. Defaults to the value of the tab
+        """Returns the id for this tab group.
+
+        Defaults to the value of the tab
         group's :attr:`horizon.tabs.Tab.slug`.
         """
         return self.slug
 
     def get_default_classes(self):
-        """Returns a list of the default classes for the tab group. Defaults to
-        ``["nav", "nav-tabs", "ajax-tabs"]``.
+        """Returns a list of the default classes for the tab group.
+
+        Defaults to ``["nav", "nav-tabs", "ajax-tabs"]``.
         """
-        default_classes = super(TabGroup, self).get_default_classes()
+        default_classes = super().get_default_classes()
         default_classes.extend(CSS_TAB_GROUP_CLASSES)
         return default_classes
 
     def tabs_not_available(self):
-        """In the event that no tabs are either allowed or enabled, this method
+        """The fallback handler if no tabs are either allowed or enabled.
+
+        In the event that no tabs are either allowed or enabled, this method
         is the fallback handler. By default it's a no-op, but it exists
         to make redirecting or raising exceptions possible for subclasses.
         """
-        pass
 
     def _set_active_tab(self):
         marked_active = None
@@ -214,8 +266,7 @@ class TabGroup(html.HTMLElement):
 
 
 class Tab(html.HTMLElement):
-    """A reusable interface for constructing a tab within a
-    :class:`~horizon.tabs.TabGroup`.
+    """A reusable interface for constructing a tab within a TabGroup.
 
     .. attribute:: name
 
@@ -257,13 +308,13 @@ class Tab(html.HTMLElement):
     preload = True
     _active = None
     permissions = []
+    policy_rules = None
 
-    def __init__(self, tab_group, request=None):
-        super(Tab, self).__init__()
+    def __init__(self, tab_group, request=None, policy_rules=None):
+        super().__init__()
         # Priority: constructor, class-defined, fallback
         if not self.name:
             raise ValueError("%s must have a name." % self.__class__.__name__)
-        self.name = six.text_type(self.name)  # Force unicode.
         if not self.slug:
             raise ValueError("%s must have a slug." % self.__class__.__name__)
         self.tab_group = tab_group
@@ -272,6 +323,7 @@ class Tab(html.HTMLElement):
             self._allowed = self.allowed(request) and (
                 self._has_permissions(request))
             self._enabled = self.enabled(request)
+        self.policy_rules = policy_rules or []
 
     def __repr__(self):
         return "<%s: %s>" % (self.__class__.__name__, self.slug)
@@ -301,9 +353,10 @@ class Tab(html.HTMLElement):
         return getattr(self, "_data", None) is not None
 
     def render(self):
-        """Renders the tab to HTML using the
+        """Renders the tab to HTML.
+
         :meth:`~horizon.tabs.Tab.get_context_data` method and
-        the :meth:`~horizon.tabs.Tab.get_template_name` method.
+        the :meth:`~horizon.tabs.Tab.get_template_name` method are called.
 
         If :attr:`~horizon.tabs.Tab.preload` is ``False`` and ``force_load``
         is not ``True``, or
@@ -317,14 +370,14 @@ class Tab(html.HTMLElement):
             context = self.data
         except exceptions.Http302:
             raise
-        except Exception:
-            exc_type, exc_value, exc_traceback = sys.exc_info()
-            raise six.reraise(TemplateSyntaxError, exc_value, exc_traceback)
+        except Exception as e:
+            raise TemplateSyntaxError from e
         return render_to_string(self.get_template_name(self.request), context)
 
     def get_id(self):
-        """Returns the id for this tab. Defaults to
-        ``"{{ tab_group.slug }}__{{ tab.slug }}"``.
+        """Returns the id for this tab.
+
+        Defaults to ``"{{ tab_group.slug }}__{{ tab.slug }}"``.
         """
         return SEPARATOR.join([self.tab_group.slug, self.slug])
 
@@ -332,9 +385,10 @@ class Tab(html.HTMLElement):
         return "=".join((self.tab_group.param_name, self.get_id()))
 
     def get_default_classes(self):
-        """Returns a list of the default classes for the tab. Defaults to
-        and empty list (``[]``), however additional classes may be added
-        depending on the state of the tab as follows:
+        """Returns a list of the default classes for the tab.
+
+        Defaults to and empty list (``[]``), however additional classes may
+        be added depending on the state of the tab as follows:
 
         If the tab is the active tab for the tab group, in which
         the class ``"active"`` will be added.
@@ -342,7 +396,7 @@ class Tab(html.HTMLElement):
         If the tab is not enabled, the classes the class ``"disabled"``
         will be added.
         """
-        default_classes = super(Tab, self).get_default_classes()
+        default_classes = super().get_default_classes()
         if self.is_active():
             default_classes.extend(CSS_ACTIVE_TAB_CLASSES)
         if not self._enabled:
@@ -362,14 +416,17 @@ class Tab(html.HTMLElement):
         return self.template_name
 
     def get_context_data(self, request, **kwargs):
-        """This method should return a dictionary of context data used to
-        render the tab. Required.
+        """Return a dictionary of context data used to render the tab.
+
+        Required.
         """
         return kwargs
 
     def enabled(self, request):
-        """Determines whether or not the tab should be accessible
-        (e.g. be rendered into the HTML on load and respond to a click event).
+        """Determines whether or not the tab should be accessible.
+
+        For example, the tab should be rendered into the HTML
+        on load and respond to a click event.
 
         If a tab returns ``False`` from ``enabled`` it will ignore the value
         of ``preload`` and only render the HTML of the tab after being clicked.
@@ -383,9 +440,14 @@ class Tab(html.HTMLElement):
 
         Tab instances can override this method to specify conditions under
         which this tab should not be shown at all by returning ``False``.
-
-        The default behavior is to return ``True`` for all cases.
         """
+        if not self.policy_rules:
+            return True
+
+        policy_check = utils_settings.import_setting("POLICY_CHECK_FUNCTION")
+
+        if policy_check:
+            return policy_check(self.policy_rules, request)
         return True
 
     def post(self, request, *args, **kwargs):
@@ -396,12 +458,10 @@ class Tab(html.HTMLElement):
 
         The default behavior is to ignore POST data.
         """
-        pass
 
 
 class TableTab(Tab):
-    """A :class:`~horizon.tabs.Tab` class which knows how to deal with
-    :class:`~horizon.tables.DataTable` classes rendered inside of it.
+    """A Tab class which knows how to deal with DataTable classes inside of it.
 
     This distinct class is required due to the complexity involved in handling
     both dynamic tab loading, dynamic table updating and table actions all
@@ -416,24 +476,30 @@ class TableTab(Tab):
         need to define a corresponding ``get_{{ table_name }}_data`` method
         as with :class:`~horizon.tables.MultiTableView`.
     """
-    table_classes = None
+    table_classes = []
 
     def __init__(self, tab_group, request):
-        super(TableTab, self).__init__(tab_group, request)
+        super().__init__(tab_group, request)
         if not self.table_classes:
             class_name = self.__class__.__name__
             raise NotImplementedError("You must define a table_class "
                                       "attribute on %s" % class_name)
         # Instantiate our table classes but don't assign data yet
-        table_instances = [(table._meta.name,
-                            table(request, **tab_group.kwargs))
-                           for table in self.table_classes]
+        if self._allowed:
+            table_instances = [(table._meta.name,
+                                table(request, **tab_group.kwargs))
+                               for table in self.table_classes]
+        else:
+            # When a corresponding tab is not allowed, there is no need to
+            # instantiate table classes (Related to bug 1791296).
+            table_instances = []
         self._tables = OrderedDict(table_instances)
         self._table_data_loaded = False
 
     def load_table_data(self):
-        """Calls the ``get_{{ table_name }}_data`` methods for each table class
-        and sets the data on the tables.
+        """Calls the ``get_{{ table_name }}_data`` methods for each table class.
+
+        When returning, the loaded data is set on the tables.
         """
         # We only want the data to be loaded once, so we track if we have...
         if not self._table_data_loaded:
@@ -456,13 +522,15 @@ class TableTab(Tab):
             self._table_data_loaded = True
 
     def get_context_data(self, request, **kwargs):
-        """Adds a ``{{ table_name }}_table`` item to the context for each table
-        in the :attr:`~horizon.tabs.TableTab.table_classes` attribute.
+        """Adds a ``{{ table_name }}_table`` item to the context for each table.
+
+        The target tables are specified by
+        the :attr:`~horizon.tabs.TableTab.table_classes` attribute.
 
         If only one table class is provided, a shortcut ``table`` context
         variable is also added containing the single table.
         """
-        context = super(TableTab, self).get_context_data(request, **kwargs)
+        context = super().get_context_data(request, **kwargs)
         # If the data hasn't been manually loaded before now,
         # make certain it's loaded before setting the context.
         self.load_table_data()
@@ -478,3 +546,7 @@ class TableTab(Tab):
 
     def has_more_data(self, table):
         return False
+
+
+class DetailTabsGroup(TabGroup):
+    template_name = "horizon/common/_detail_tab_group.html"
