@@ -77,8 +77,12 @@ class Service(base.APIDictWrapper):
         super().__init__(service, *args, **kwargs)
         self.public_url = base.get_url_for_service(service, region,
                                                    'publicURL')
-        self.url = base.get_url_for_service(service, region,
-                                            settings.OPENSTACK_ENDPOINT_TYPE)
+        if (service.get('type') == 'identity' and
+                settings.OPENSTACK_KEYSTONE_ENDPOINT_TYPE):
+            endpoint_type = settings.OPENSTACK_KEYSTONE_ENDPOINT_TYPE
+        else:
+            endpoint_type = settings.OPENSTACK_ENDPOINT_TYPE
+        self.url = base.get_url_for_service(service, region, endpoint_type)
         if self.url:
             self.host = parse.urlparse(self.url).hostname
         else:
@@ -160,7 +164,7 @@ def keystoneclient(request, admin=False, force_scoped=False):
 
     if admin and not policy.check((("identity", "admin_required"),), request):
         raise exceptions.NotAuthorized
-    endpoint_type = settings.OPENSTACK_ENDPOINT_TYPE
+    endpoint_type = settings.OPENSTACK_KEYSTONE_ENDPOINT_TYPE
 
     # Take care of client connection caching/fetching a new client.
     # Admin vs. non-admin clients are cached separately for token matching.
@@ -217,7 +221,7 @@ def domain_delete(request, domain_id):
 
 @profiler.trace
 def domain_list(request):
-    manager = keystoneclient(request, admin=True).domains
+    manager = keystoneclient(request, admin=True, force_scoped=True).domains
     return manager.list()
 
 
@@ -464,7 +468,8 @@ def user_verify_admin_password(request, admin_password):
     # verify if it's correct.
     client = keystone_client_v3
     try:
-        endpoint = _get_endpoint_url(request, 'publicURL')
+        endpoint = _get_endpoint_url(
+            request, settings.OPENSTACK_KEYSTONE_ENDPOINT_TYPE)
         insecure = settings.OPENSTACK_SSL_NO_VERIFY
         cacert = settings.OPENSTACK_SSL_CACERT
         client.Client(
@@ -494,6 +499,44 @@ def user_update_tenant(request, user, project, admin=True):
     return manager.update(user, project=project)
 
 
+@profiler.trace
+def credential_create(request, user, type, blob, project=None):
+    manager = keystoneclient(request).credentials
+    return manager.create(user=user, type=type, blob=blob, project=project)
+
+
+@profiler.trace
+def credential_delete(request, credential_id):
+    manager = keystoneclient(request, admin=True).credentials
+    return manager.delete(credential_id)
+
+
+@profiler.trace
+def credential_get(request, credential_id, admin=True):
+    manager = keystoneclient(request, admin=admin).credentials
+    return manager.get(credential_id)
+
+
+@profiler.trace
+def credentials_list(request, user=None):
+    manager = keystoneclient(request).credentials
+    return manager.list(user=user)
+
+
+@profiler.trace
+def credential_update(request, credential_id, user,
+                      type=None, blob=None, project=None):
+    manager = keystoneclient(request, admin=True).credentials
+    try:
+        return manager.update(credential=credential_id,
+                              user=user,
+                              type=type,
+                              blob=blob,
+                              project=project)
+    except keystone_exceptions.Conflict:
+        raise exceptions.Conflict()
+
+
 @profiler.trace
 def group_create(request, domain_id, name, description=None):
     manager = keystoneclient(request, admin=True).groups
