@@ -12,9 +12,10 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from django.conf.urls import url
-from openstack_dashboard.contrib.developer.resource_browser import views
+from django.urls import re_path
+
+from horizon.browsers.views import AngularIndexView
 
 urlpatterns = [
-    url('', views.IndexView.as_view(), name='index'),
+    re_path('', AngularIndexView.as_view(), name='index'),
 ]
