@@ -52,7 +52,8 @@ class CreateAggregateWorkflowTests(BaseAggregateWorkflowTests):
         self.assertQuerysetEqual(
             workflow.steps,
             ['<SetAggregateInfoStep: set_aggregate_info>',
-             '<AddHostsToAggregateStep: add_host_to_aggregate>'])
+             '<AddHostsToAggregateStep: add_host_to_aggregate>'],
+            transform=repr)
         self.mock_service_list.assert_called_once_with(
             test.IsHttpRequest(),
             binary='nova-compute')
@@ -104,7 +105,7 @@ class CreateAggregateWorkflowTests(BaseAggregateWorkflowTests):
         workflow_data['name'] = ''
         workflow_data['availability_zone'] = ''
         self._test_generic_create_aggregate(workflow_data, aggregate, (), 1,
-                                            u'This field is required')
+                                            'This field is required.')
 
     def test_create_aggregate_fails_missing_fields_existing_aggregates(self):
         aggregate = self.aggregates.first()
@@ -115,14 +116,14 @@ class CreateAggregateWorkflowTests(BaseAggregateWorkflowTests):
 
         self._test_generic_create_aggregate(workflow_data, aggregate,
                                             existing_aggregates, 1,
-                                            u'This field is required')
+                                            'This field is required.')
 
     def test_create_aggregate_fails_duplicated_name(self):
         aggregate = self.aggregates.first()
         existing_aggregates = self.aggregates.list()
         workflow_data = self._get_create_workflow_data(aggregate)
         expected_error_message = html \
-            .escape(u'The name "%s" is already used by another host aggregate.'
+            .escape('The name "%s" is already used by another host aggregate.'
                     % aggregate.name)
 
         self._test_generic_create_aggregate(workflow_data, aggregate,
@@ -191,25 +192,6 @@ class CreateAggregateWorkflowTests(BaseAggregateWorkflowTests):
 
 class AggregatesViewTests(test.BaseAdminViewTests):
 
-    @test.create_mocks({
-        api.keystone: ['tenant_list'],
-        api.nova: ['extension_supported']})
-    def test_panel_not_available(self):
-        self.mock_tenant_list.return_value = self.tenants.list()
-        self.mock_extension_supported.return_value = False
-
-        self.patchers['aggregates'].stop()
-        res = self.client.get(reverse('horizon:admin:overview:index'))
-        self.assertNotIn(b'Host Aggregates', res.content)
-        self.mock_tenant_list.assert_called_once_with(test.IsHttpRequest())
-        self.assertEqual(self.mock_extension_supported.call_count, 3)
-        expected_calls = [mock.call(a, test.IsHttpRequest())
-                          for a in ['SimpleTenantUsage',
-                                    'SimpleTenantUsage',
-                                    'Aggregates']]
-        self.mock_extension_supported.assert_has_calls(
-            expected_calls)
-
     @test.create_mocks({
         api.nova: ['aggregate_details_list',
                    'availability_zone_list']})
@@ -273,7 +255,7 @@ class AggregatesViewTests(test.BaseAdminViewTests):
                      'availability_zone': aggregate.availability_zone}
 
         self._test_generic_update_aggregate(form_data, aggregate, 1,
-                                            u'This field is required')
+                                            'This field is required.')
 
     def test_update_aggregate_fails_missing_az_field(self):
         aggregate = self.aggregates.first()
@@ -283,7 +265,7 @@ class AggregatesViewTests(test.BaseAdminViewTests):
 
         self._test_generic_update_aggregate(
             form_data, aggregate, 1,
-            u'The new availability zone can&#39;t be empty')
+            'The new availability zone can&#39;t be empty')
 
 
 class ManageHostsTests(test.BaseAdminViewTests):
