@@ -15,11 +15,12 @@
 import logging
 
 from django.conf import settings
+from django import shortcuts
 from django.template import defaultfilters as filters
 from django.urls import reverse
 from django.utils.http import urlencode
-from django.utils.translation import ugettext_lazy as _
-from django.utils.translation import ungettext_lazy
+from django.utils.translation import gettext_lazy as _
+from django.utils.translation import ngettext_lazy
 
 from keystoneclient import exceptions as keystoneclient_exceptions
 
@@ -91,7 +92,7 @@ class EditDomainLink(tables.LinkAction):
 class DeleteDomainsAction(tables.DeleteAction):
     @staticmethod
     def action_present(count):
-        return ungettext_lazy(
+        return ngettext_lazy(
             "Delete Domain",
             "Delete Domains",
             count
@@ -99,7 +100,7 @@ class DeleteDomainsAction(tables.DeleteAction):
 
     @staticmethod
     def action_past(count):
-        return ungettext_lazy(
+        return ngettext_lazy(
             "Deleted Domain",
             "Deleted Domains",
             count
@@ -125,7 +126,7 @@ class DeleteDomainsAction(tables.DeleteAction):
 class DisableDomainsAction(tables.BatchAction):
     @staticmethod
     def action_present(count):
-        return ungettext_lazy(
+        return ngettext_lazy(
             "Disable Domain",
             "Disable Domains",
             count
@@ -133,7 +134,7 @@ class DisableDomainsAction(tables.BatchAction):
 
     @staticmethod
     def action_past(count):
-        return ungettext_lazy(
+        return ngettext_lazy(
             "Disabled Domain",
             "Disabled Domains",
             count
@@ -165,7 +166,7 @@ class DisableDomainsAction(tables.BatchAction):
 class EnableDomainsAction(tables.BatchAction):
     @staticmethod
     def action_present(count):
-        return ungettext_lazy(
+        return ngettext_lazy(
             "Enable Domain",
             "Enable Domains",
             count
@@ -173,7 +174,7 @@ class EnableDomainsAction(tables.BatchAction):
 
     @staticmethod
     def action_past(count):
-        return ungettext_lazy(
+        return ngettext_lazy(
             "Enabled Domain",
             "Enabled Domains",
             count
@@ -246,9 +247,11 @@ class SetDomainContext(tables.Action):
                 messages.success(request,
                                  _('Domain Context updated to Domain %s.') %
                                  domain.name)
+                return shortcuts.redirect(request.get_full_path())
             except Exception:
                 messages.error(request,
                                _('Unable to set Domain Context.'))
+                return shortcuts.redirect(request.get_full_path())
 
 
 class UnsetDomainContext(tables.Action):
@@ -268,6 +271,7 @@ class UnsetDomainContext(tables.Action):
             request.session.pop("domain_context")
             request.session.pop("domain_context_name")
             messages.success(request, _('Domain Context cleared.'))
+            return shortcuts.redirect(request.get_full_path())
 
 
 class DomainsTable(tables.DataTable):
