@@ -25,9 +25,9 @@ def _get_root_path():
     return os.path.dirname(os.path.abspath(__file__))
 
 
-# ---------------------------------------------------
-# Override horizn, openstack_auth and Django settings
-# ---------------------------------------------------
+# ----------------------------------------------------
+# Override horizon, openstack_auth and Django settings
+# ----------------------------------------------------
 
 WEBROOT = '/'  # from openstack_auth
 
@@ -353,6 +353,10 @@ OPENSTACK_ENDPOINT_TYPE = 'publicURL'
 # external to the OpenStack environment. The default is None. This
 # value should differ from OPENSTACK_ENDPOINT_TYPE if used.
 SECONDARY_ENDPOINT_TYPE = None
+# OPENSTACK_KEYSTONE_ENDPOINT_TYPE specifies the endpoint type use from
+# service catalog when looking up the Keystone (identity) endpoint. This
+# parameter overrides OPENSTACK_ENDPOINT_TYPE.
+OPENSTACK_KEYSTONE_ENDPOINT_TYPE = None
 
 # Set True to disable SSL certificate checks
 # (useful for self-signed certificates):
@@ -453,6 +457,10 @@ OPENSTACK_NEUTRON_NETWORK = {
     # list, the field will be a regular input field.
     # e.g. ['default', 'test']
     'physical_networks': [],
+
+    # Show the column with the count of dhcp agents in the admin network view.
+    # Disable this on large deployments to avoid slowing down of this view.
+    'show_agents_column': True,
 }
 
 # This settings controls whether IP addresses of servers are retrieved from
