@@ -15,5 +15,5 @@ from openstack_dashboard.test.integration_tests.pages import basepage
 
 class OverviewPage(basepage.BaseNavigationPage):
     def __init__(self, driver, conf):
-        super(OverviewPage, self).__init__(driver, conf)
+        super().__init__(driver, conf)
         self._page_title = "Overview"
